#
# spec file for package python-msal
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-msal
Version:        1.6.0
Release:        3.3.1
Summary:        Microsoft Authentication Library (MSAL) for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/AzureAD/microsoft-authentication-library-for-python
Source:         https://files.pythonhosted.org/packages/source/m/msal/msal-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyJWT >= 1.0.0
Requires:       python-cryptography >= 0.6
Requires:       python-requests >= 2.0.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyJWT >= 1.0.0}
BuildRequires:  %{python_module requests >= 2.0.0}
# /SECTION
%python_subpackages

%description
The Microsoft Authentication Library (MSAL) for Python library enables your app
to access the Microsoft Cloud by supporting authentication of users with Microsoft
Azure Active Directory accounts (AAD) and Microsoft Accounts (MSA) using industry
standard OAuth2 and OpenID Connect.

%prep
%setup -q -n msal-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.md
%{python_sitelib}/*

%changelog
* Tue Dec 15 2020 adrian.glaubitz@suse.com
- Include in SLE-15 (bsc#1176785, jsc#ECO-3105, jsc#PM-2352)
* Fri Nov 13 2020 adrian.glaubitz@suse.com
- Update to version 1.6.0
  + New Feature: ```ConfidentialClientApplication``` accepts private
    key encrypted by a passphrase. (#232, #270)
  + Enhancement: Provides different exception and messages while
    encountering transient error during tenant discovery (#263, #269)
- from version 1.5.1
  + Bugfix: We now cache tokens by specified environment, not by OIDC Discovery.
    This won't matter most of the time, but it can be needed when your tenant is
    in transitional state while migrating to a different cloud. (#247)
  + Bugfix: We now make sure one app's sign-out operation would be successful even
    when another app is acquiring token from cache at the same time. (#258, #262)
- Update Requires from setup.py
* Tue Sep  8 2020 adrian.glaubitz@suse.com
- Update to version 1.5.0
  + Added support for setting client capabilities to enable
    CAE(Continuous Access Evaluation) (#240, #174)
  + Device code endpoint is now fetched from open-id configuration,
    if available. (#245, #242)
  + Fixes in test cases (#239, #211)
* Fri Aug 28 2020 adrian.glaubitz@suse.com
- Update to version 1.4.3
  + Bugfix: A side effect in previous release prevented reading some
    tokens from a different authority alias (#235, #236)
- from version 1.4.2
  + Bugfix: Changed case of messageID in WS-Trust Requests (#228 , #230 )
  + Bugfix: Removed content-type header sent in request to Mex endpoint (#226 , #227 )
  + Bugfix: Bypasses cache lookup for authority alias if no refresh token found (#223, #225 )
- from version 1.4.1
  + Reverts Application Initializer will not send network requests
    introduced in MSAL Python 1.4.0 (#205, #216, #187)
- from version 1.4.0
  + Enhancement: Application initializer will not send network requests. (#205, #187)
  + Enhancement: Improved handling of errors in ADAL to MSAL token migration scenario. (#209, #208)
  + Added changelog in PYPI (#203, #202)
  + Other readme and reference docs adjustments (#200, #197)
* Tue Jun 16 2020 adrian.glaubitz@suse.com
- Update to version 1.3.0
  + New feature: class ```ClientApplication``` accepts a new optional parameter
    ```http_client```. You can provide your own HTTP client to have different
    behavior. (#169) Please refer to API Reference doc.
  + New feature: method ```get_authorization_request_url()``` accepts a new optional
    parameter ```domain_hint```. (#158, #181)
    Please refer to API Reference doc.
  + New feature: A new method ```acquire_token_by_refresh_token()``` to help migrating
    refresh tokens from elsewhere to MSAL Python. (#193)
    Its usage is demonstrated in this sample.
- from version 1.2.0
  + New ```nonce``` parameter is provided in ```both get_authorization_request_url(..., nonce=...)```
    and ```acquire_token_by_authorization_code(..., nonce=...)``` method, so
    that you can use them to mitigate replay attacks, per OIDC specs. (#128, #173).
- from version 1.1.0
    + New ```acquire_token_silent_with_error(...)``` method to expose conditional
    access error classifications (#143, closes #57).
    + App developers can opt in to provide their app's name and version for Microsoft
    Telemetry, so that we can understand your usage pattern and serve you better.
    (#136 closes #130)
    + Internally,
  * Collect anonymous telemetry data to help us improve MSAL Python (#103)
  * Test cases cover ADFS 2019 on-premise scenarios (#142, closes #132)
  * Switched to our latest lab apis for better test infrastructure (#108, #133, #134, #135)
* Tue Feb 18 2020 adrian.glaubitz@suse.com
- Initial build
  + Version 1.1.0
